==> phplist-2.10.5p0.tgz: lists/admin/lan/pt-br/import4.php <==
<?php 
$lan = array(

  'add_list' => 'Adicionar uma lista', //duplicada em import1_text
  'cant_connect' => 'n&atilde;o foi poss&iacute;vel conectar &agrave; base de dados',
  'no_users_to_copy' => 'Nenhum usu&aacute;rio para se copiado, o prefixo est&aacute; correto?',
  'remote_server' => 'Por favor, insira os dados do Servidor remoto',
  'server' => 'Servidor:',
  'user' => 'Usu&aacute;rio:',
  'passwd' => 'Senha:',
  'database' => 'Nome da Base de Dados:',
  'table_prefix' => 'Prefixo da tablea:',
  'usertable_prefix' => 'Prefixo da tabela de usu&aacuterios:',
  'select_lists' => 'Selecione as listas nas quais voc&ecirc; quer adicionar os emails',
  'copy_lists' => 'Copiar listas do servidor local (as listas s&atilde;o encontradas atrav&eacute;s do nome)',
  'users_as_html' => 'Marcar novos usu&aacute;rios como HTML:',
  'info_overwrite_existing' => 'Se voc&ecirc; marcar "Sobrescrever Existente", a informa&ccedil;&atilde;o do usu&aacute;rio na base de dados ser&aacute; substitu&iacute;da pela informa&ccedil;&atilde;o importada. Os usu&aacute;rios s&atilde;o encontrados atrav&eacute;s do email.',
  'overwrite_existing' => 'Sobrescrever existente:',
  'connecting_remote' => 'Conectando com a base de dados remota',
  'getting_data' => 'Obtendo dados de ',
  'remote_version' => 'A vers&aacute;o remota &eacute;',
  'remote_has' => 'Remote version has',
  'users' => 'usu&aacute;rios',
  'lists' => 'listas',
  'copying_lists' => 'Copiando listas',
  'list' => 'Lista',
  'exists_locally' => 'localmente existente',
  'created_locally' => 'localmente criada',
  'remote_list' => 'Lista remota',
  'not_created' => 'n&atilde;o criado',
  'copying_attribs' => 'Copiando atributos',
  'attrib' => 'Atributo',
  'copying_users' => 'Copiando usu&acute;rios',
  'overwrite_local' => 'sobrescrevendo dados locais',
  'keep_local' => 'mantendo dados locais',
  'new_user' => '&eacute; um novo usu&aacute;rio',
  'no_mapped_attrib' => 'Error, no mapped attribute for',
  'no_local_list' => 'Erro, nenhuma lista local definida para',
  'No lists available' => 'Nenhuma lista dispon&iacute;vel',
  'Done' => 'Conclu&iacute;do',
  'new users' => 'novos usu&aacute;rios',
  'and' => 'e',
  'existing users' => 'usu&aacute;rio existentes',
  'continue' => 'Continuar',

);
?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/pt-br/import4.php <==
<?php 
$lan = array(
  'import is not available' => 'importa&ccedil;&atilde;o n&atilde;o est&aacute; dispon&iacute;vel',
  'add_list' => 'Adicionar uma lista', //duplicada em import1_text
  'cant_connect' => 'n&atilde;o foi poss&iacute;vel conectar &agrave; base de dados',
  'no_users_to_copy' => 'Nenhum usu&aacute;rio a ser copiado, o prefixo est&aacute; correto?',
  'remote_server' => 'Por favor, insira os dados do Servidor remoto',
  'server' => 'Servidor:',
  'user' => 'Usu&aacute;rio:',
  'passwd' => 'Senha:',
  'database' => 'Nome da Base de Dados:',
  'table_prefix' => 'Prefixo da tabela:',
  'usertable_prefix' => 'Prefixo da tabela de usu&aacute;rios:',
  'select_lists' => 'Selecione as listas nas quais voc&ecirc; quer adicionar os emails',
  'copy_lists' => 'Copiar listas do servidor local (as listas s&atilde;o encontradas atrav&eacute;s do nome)',
  'users_as_html' => 'Marcar novos usu&aacute;rios como HTML:',
  'info_overwrite_existing' => 'Se voc&ecirc; marcar "Sobrescrever Existente", a informa&ccedil;&atilde;o do usu&aacute;rio na base de dados ser&aacute; substitu&iacute;da pela informa&ccedil;&atilde;o importada. Os usu&aacute;rios s&atilde;o encontrados atrav&eacute;s do email.',
  'overwrite_existing' => 'Sobrescrever existente:',
  'connecting_remote' => 'Conectando com a base de dados remota',
  'getting_data' => 'Obtendo dados de ',
  'remote_version' => 'A vers&atilde;o remota &eacute;',
  'remote_has' => 'A vers&atilde;o remota tem',
  'users' => 'usu&aacute;rios',
  'lists' => 'listas',
  'copying_lists' => 'Copiando listas',
  'list' => 'Lista',
  'exists_locally' => 'j&aacute; existe',
  'created_locally' => 'localmente criada',
  'remote_list' => 'Lista remota',
  'not_created' => 'n&atilde;o criado',
  'copying_attribs' => 'Copiando atributos',
  'attrib' => 'Atributo',
  'copying_users' => 'Copiando usu&aacute;rios',
  'overwrite_local' => 'sobrescrevendo dados locais',
  'keep_local' => 'mantendo dados locais',
  'new_user' => '&eacute; um novo usu&aacute;rio',
  'no_mapped_attrib' => 'Erro: n&atilde;o h&aacute; atributos mapeados para',
  'no_local_list' => 'Erro, nenhuma lista local definida para',
  'No lists available' => 'Nenhuma lista dispon&iacute;vel',
  'Done' => 'Conclu&iacute;do',
  'new users' => 'novos usu&aacute;rios',
  'and' => 'e',
  'existing users' => 'usu&aacute;rio existentes',
  'continue' => 'Continuar',

);
?>
